Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/owncloud/client.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorChristian Kamm <mail@ckamm.de>2018-06-14 15:35:06 +0300
committerckamm <mail@ckamm.de>2018-06-19 13:47:23 +0300
commit99116acdcaba3fb068ba63bdcd759836f2017a92 (patch)
tree022a7e02cdde60ef0891264b0ee74ed5763fe90f /src/gui/owncloudgui.h
parent92219c5bf7c07ee53fc463da4b082e50d17a0e2d (diff)
Tray workarounds #6545
* Disentangle the previous 'qdbusWorkarounds' into three different things * Make not trusting tray.isVisible() a new workaround * Introduce env vars for all workaround flags * Use the workaround flags for OSX * Determine workaround flags for KDE when the plasma integration plugin is missing
Diffstat (limited to 'src/gui/owncloudgui.h')
-rw-r--r--src/gui/owncloudgui.h15
1 files changed, 10 insertions, 5 deletions
diff --git a/src/gui/owncloudgui.h b/src/gui/owncloudgui.h
index 9bc136472..9fcb2f50a 100644
--- a/src/gui/owncloudgui.h
+++ b/src/gui/owncloudgui.h
@@ -124,14 +124,19 @@ private:
// tray's menu
QScopedPointer<QMenu> _contextMenu;
- // Manually tracking whether the context menu is visible, but only works
- // on OSX because aboutToHide is not reliable everywhere.
- bool _contextMenuVisibleOsx;
+ // Manually tracking whether the context menu is visible via aboutToShow
+ // and aboutToHide. Unfortunately aboutToHide isn't reliable everywhere
+ // so this only gets used with _workaroundManualVisibility (when the tray's
+ // isVisible() is unreliable)
+ bool _contextMenuVisibleManual;
QMenu *_recentActionsMenu;
QVector<QMenu *> _accountMenus;
- bool _qdbusmenuWorkaround;
- QTimer _workaroundBatchTrayUpdate;
+ bool _workaroundShowAndHideTray = false;
+ bool _workaroundNoAboutToShowUpdate = false;
+ bool _workaroundFakeDoubleClick = false;
+ bool _workaroundManualVisibility = false;
+ QTimer _delayedTrayUpdateTimer;
QMap<QString, QPointer<ShareDialog>> _shareDialogs;
QAction *_actionLogin;